Coverage for C:\src\imod-python\imod\prepare\__init__.py: 100%

1"""

2 Prepare model input.

3

4 A various selection of functions to mangle your data from one form into another,

5 such that it will fit into your model. This includes

6:func:`imod.prepare.reproject` for reprojecting grids, and

7:func:`imod.prepare.rasterize` to create grids from vector files.

8

9 Naturally you are free to write your own functions or one of the many existing

10 ones from other packages. As long as you keep your data in the expected

11``xarray.DataArray`` and ``pandas.DataFrame`` formats, this will work. In some

12 cases, such as :class:`imod.prepare.Regridder`, these methods are optimized for

13 speed by making use of the Numba compiler, to be able to regrid large datasets.

14"""

15

16 from imod.prepare import spatial, subsoil, surface_water

17 from imod.prepare.layer import (

18 create_layered_top,

19 get_lower_active_grid_cells,

20 get_lower_active_layer_number,

21 get_upper_active_grid_cells,

22 get_upper_active_layer_number,

23)

24 from imod.prepare.layerregrid import LayerRegridder

25 from imod.prepare.regrid import Regridder

26 from imod.prepare.reproject import reproject

27 from imod.prepare.spatial import (

28 celltable,

29 fill,

30 gdal_rasterize,

31 laplace_interpolate,

32 polygonize,

33 rasterize,

34 rasterize_celltable,

35 zonal_aggregate_polygons,

36 zonal_aggregate_raster,

37)

38 from imod.prepare.topsystem import (

39 ALLOCATION_OPTION,

40 DISTRIBUTING_OPTION,

41 allocate_drn_cells,

42 allocate_ghb_cells,

43 allocate_rch_cells,

44 allocate_riv_cells,

45 c_leakage,

46 c_radial,

47 distribute_drn_conductance,

48 distribute_ghb_conductance,

49 distribute_riv_conductance,

50)

51 from imod.prepare.voxelize import Voxelizer

52 from imod.prepare.wells import assign_wells